#
# spec file for package git-deps
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define skip_python2 1
Name:           git-deps
Version:        1.1.0+git.1696898573.89d51e8
Release:        2.3
Summary:        Tool to analyze git deps
License:        GPL-2.0-only
Group:          Development/Tools/Version Control
URL:            https://github.com/aspiers/git-deps
Source:         %{name}-%{version}.tar.xz
# PATCH-FIX-UPSTREAM dont-use-st-markdown.patch gh#aspiers/git-deps!118 mcepl@suse.com
# update syntax to the current levels and eliminate (almost) setup.py
Patch0:         dont-use-st-markdown.patch
# PATCH-FIX-UPSTREAM pygit2-1.15.0.patch gh#aspiers/git-deps!129 mcepl@suse.com
# make compatible with pygit2 1.15.0
Patch1:         pygit2-1.15.0.patch
# PATCH-FIX-UPSTREAM no-pkg-resources.patch gh#aspiers/git-deps!131 mcepl@suse.com
# Don't depend on pkg_resources
Patch2:         no-pkg-resources.patch
BuildRequires:  fdupes
BuildRequires:  git
BuildRequires:  python-rpm-macros
BuildRequires:  python3-pip
BuildRequires:  python3-pygit2
# Because of version = attr: package.__version__
BuildRequires:  python3-setuptools >= 46.4.0
BuildRequires:  python3-wheel
BuildRequires:  python3-pytest
# BuildRequires:  python3-certifi
Requires:       python3-pygit2
# for html subpackage
Requires:       python3-Flask
#Requires:       nodejs-browserify # broken/missing
Requires:       npm
Requires:       git
BuildArch:      noarch

%description
Tool to analyze git dependencies

file bugs at https://github.com/aspiers/git-deps/issues

%package html
Summary:        Tool to analyze git deps - HTML parts
Group:          Development/Tools/Version Control

%description html
Documentation for git-deps.

%prep
%autosetup -p1 -n %{name}-%{version}

%build
%python3_pyproject_wheel

%install
%python3_pyproject_install
install -D -m 755 %{buildroot}%{python3_sitelib}/git_deps/handler.py \
    %{buildroot}%{_bindir}/gitfile-handler
%python3_fix_shebang
%fdupes %{buildroot}%{python3_sitelib}

%check
# Test doesn't work with tarball, requires .git/ directory with full history
# # because of gh#libgit2/pygit2$1311
# export PYTEST_ADDOPTS="--ignore tests/test_GitUtils.py"
# %%python3_pytest

%files
%license LICENSE.txt
%doc AUTHORS.rst CONTRIBUTING.md CHANGES.rst README.md USAGE.md
%doc HISTORY.md USE-CASES.md
%{_bindir}/git-deps
# %%{_bindir}/git-fixup
%{_bindir}/gitfile-handler
%{python3_sitelib}/git_deps
%{python3_sitelib}/git_deps-1.1.0*-info

%files html
%doc docs

%changelog
* Mon Jul 29 2024 Matej Cepl <mcepl@cepl.eu>
- Fix dont-use-st-markdown.patch (don't list packages explicitly,
  generate the list)
* Thu Jul 18 2024 mcepl@cepl.eu
- Update to version 1.1.0+git.1696898573.89d51e8:
  * Only use pygit2's blame via opt-in
  * Blame via pygit2 instead of subprocess
  * Fix deps fetching on the root commit
  * Start test suite of running git-deps on itself
  * Remove dependency to six. Closes #115
  * Remove Travis config
  * Upgrade setuptools
  * Create CI.yml
  * Import `safe_join` from `werkzeug.security`
  * Drop support for Python 3.6
  * Drop setuptools-markdown
  * Handle server port in use error more gracefully (#88)
  * Fix publishing procedure
  * Expand AUTHORS.rst
  * Remove sphinx.ext.pngmath
  * Add maintainer-guide to the docs
  * Be stricter with docs
  * Update sphinx docs location
  * Update CHANGES.rst
  * Add flake8 to Travis
  * Fix some flake8 issues
  * Don't totally ignore KeyboardInterrupt
  * Improve HTML installation instructions slightly
  * Update INSTALL.md for Python 3.x (#98)
  * Update tox.ini for newer Pythons
  * Fix Travis builds (#73)
  * Use line-buffering on output (#87)
  * Bump jquery from 3.0.0 to 3.5.0 in /git_deps/html
- Remove upstreamed patches:
  - Fix-issue-with-unbuffered-text-I-O-under-python3.patch
- Add compatibility patches:
  - no-pkg-resources.patch
  - pygit2-1.15.0.patch (from gh#aspiers/git-deps!129)
* Tue Jul 18 2023 mcepl@cepl.eu
- Update to version 1.1.0+git.1655802074.8cafb5c:
  * Import `safe_join` from `werkzeug.security`
  * Drop support for Python 3.6
  * Drop setuptools-markdown
  * Handle server port in use error more gracefully (#88)
  * Fix publishing procedure
  * Expand AUTHORS.rst
  * Remove sphinx.ext.pngmath
  * Add maintainer-guide to the docs
  * Be stricter with docs
  * Update sphinx docs location
  * Update CHANGES.rst
  * Add flake8 to Travis
  * Fix some flake8 issues
  * Don't totally ignore KeyboardInterrupt
  * Improve HTML installation instructions slightly
  * Update INSTALL.md for Python 3.x (#98)
  * Update tox.ini for newer Pythons
  * Fix Travis builds (#73)
  * Use line-buffering on output (#87)
  * Bump jquery from 3.0.0 to 3.5.0 in /git_deps/html
- Remove upstreamed Fix-issue-with-unbuffered-text-I-O-under-python3.patch
- Switch package to be managed by SCM.
* Fri Sep 23 2022 pgajdos@suse.com
- do not require python-six
  https://trello.com/c/MO53MocR/143-remove-python3-six
* Mon Apr 12 2021 Matej Cepl <mcepl@suse.com>
- Fix Requires
* Sat Apr  3 2021 Matej Cepl <mcepl@suse.com>
- Remove single-package spec, this is just a regular application which
  happens to be written in Python, not a Python library.
* Thu Oct 29 2020 Bruce Rogers <brogers@suse.com>
- Fix setup.py to correctly identify the project packages git_deps
  and git_deps/listener. These were not being packaged and as a
  result the git-deps command was simply failing
- Add Fix-issue-with-unbuffered-text-I-O-under-python3.patch,
  which fixes the issue with unbuffered text I/O under python3,
  (gh#aspiers/git-deps#93).
* Mon Jun  1 2020 Matej Cepl <mcepl@suse.com>
- Extend dont-use-st-markdown.patch to include full setup()
  command instead of setup.cfg only.
* Tue Feb 18 2020 mcepl@cepl.eu
- Update to version 1.0.2+git.1559732444.7c75531:
  * add direct links to presentation videos
  * add links to blog and Nashville presentation
  * Fix link in readme to USE-CASES.md
  * Don't crash with commit messages that aren't valid utf-8
  * Use unbuffered IO
  * add Credits section
  * split off use cases to separate file
  * add missing sections to TOC
  * make CONTRIBUTING.md link consistent with others
* Thu Jun  4 2015 bwiedemann@suse.com
- add HTML parts
* Thu Jun  4 2015 bwiedemann@suse.com
- initial package
